@@ -238,10 +238,12 @@ require AutoLoader;
 	PLACE_HOLDER2
 	PLACE_HOLDER1
 );
-$VERSION = '0.16.7';
-$VERSION_NAME = 'Dromedary Samurai';
-$DefaultBrokerHost = 'localhost';
-$DefaultBrokerName = 'Broker #1';
+$VERSION = '0.13';
+$VERSION_NAME = 'Tadpole Ninja';
+$DefaultBrokerName = 'test_broker';
+# $DefaultBrokerHost = 'active';
+# $DefaultBrokerName = 'Broker #1';
+$DefaultBrokerHost = 'localhost:6449';
 $SPAM = 0;
 
 
@@ -320,21 +322,12 @@ Aw - Perl extension for the ActiveWorks C Application Development Kit
 
 =head1 SYNOPSIS
 
- use Aw;
- require Aw::Adapter;
- require Aw::Event;
- my %properties = (
-        clientId	=> 'TimeAdapter',
-        broker		=> "test\@active:7449",
-        adapterId	=> 0,
-        debug		=> 1,
-        clientGroup	=> 'devkitAdapter',
-        adapterType	=> 'Adapter40',
-        messageCatalog	=> 'time_adapter'
- );
+use Aw;
+require Aw::Adapter;
+require Aw::Event;
 
- my $adapter = new Aw::Adapter  ( \%properties ) ;
- my $event = new Aw::Event;
+my $adapter = new Aw::Adapter  ( "3.0", ) ;
+my $event = new Aw::Event;
 
 =head1 DESCRIPTION
 
@@ -348,7 +341,7 @@ Everything in the CADK include files I<should> be exported as constants.
 
 =head1 AUTHOR
 
-Daniel Yacob Mekonnen,  L<Yacob@wMUsers.Com|mailto:Yacob@wMUsers.Com>
+Daniel Yacob Mekonnen,  L<Yacob@RCN.Com|mailto:Yacob@RCN.Com>
 
 =head1 SEE ALSO
 
