@@ -1,15 +1,12 @@
 package Aw::Adapter;
 
+use strict;
+use vars qw($VERSION);
 
-BEGIN
-{
-	use strict;
-	use vars qw($VERSION);
+$VERSION = '0.1';
 
-	$VERSION = '0.3';
+use Aw;
 
-	use Aw;
-}
 
 
 sub new
@@ -66,8 +63,7 @@ my $self = shift;
 				$self->_loadProperties ( $_[0] );
 			}
 		}
-	}
-	else {
+	} else {
 		unshift ( @_, "$0" );
 		$self->_loadProperties ( \@_ );
 	}
@@ -99,37 +95,6 @@ my @args = ();
 }
 
 
-sub getStringSeqInfo
-{
-	my $result = Aw::Adapter::getStringSeqInfoRef ( @_ );
-	( wantarray ) ? @{ $result } : $result ;
-}
-
-
-
-sub getUCStringSeqInfoAsA
-{
-	my $result = Aw::Adapter::getUCStringSeqInfoAsARef ( @_ );
-	( wantarray ) ? @{ $result } : $result ;
-}
-
-
-
-sub getUCStringSeqInfoAsUTF8
-{
-	my $result = Aw::Adapter::getUCStringSeqInfoAsUTF8Ref ( @_ );
-	( wantarray ) ? @{ $result } : $result ;
-}
-
-
-
-sub getStructSeqInfo
-{
-	my $result = Aw::Adapter::getStructSeqInfoRef ( @_ );
-	( wantarray ) ? @{ $result } : $result ;
-}
-
-
 
 sub getEventDefs
 {
@@ -229,7 +194,7 @@ Enhanced interface for the Aw.xs Adapter methods.
 
 =head1 AUTHOR
 
-Daniel Yacob Mekonnen,  L<Yacob@wmUsers.Com|mailto:Yacob@wmUsers.Com>
+Daniel Yacob Mekonnen,  L<Yacob@RCN.Com|mailto:Yacob@RCN.Com>
 
 =head1 SEE ALSO
 
